@@ -95,27 +95,32 @@ def conflict_obsolete(latest_version: Version, kind: str, req_version: Version):
     return False
 
 
+class UddTimeout(Exception):
+    """Timeout while connecting to UDD."""
+
+
 async def _package_version(package: str, release: str) -> Optional[Version]:
     from .udd import connect_udd_mirror
 
-    conn = await connect_udd_mirror()
-    version = await conn.fetchval(
-        "select version from packages where package = $1 and release = $2",
-        package,
-        release,
-    )
+    try:
+        async with await connect_udd_mirror() as conn:
+            version = await conn.fetchval(
+                "select version from packages where package = $1 and release = $2",
+                package, release)
+    except asyncio.TimeoutError:
+        raise UddTimeout()
     if version is not None:
         return Version(version)
     return None
 
 
-async def _package_provides(package: str, release: str) -> Optional[Version]:
+async def _package_provides(package: str, release: str) -> Optional[List[PkgRelation]]:
     from .udd import connect_udd_mirror
 
-    conn = await connect_udd_mirror()
-    provides = await conn.fetchval(
-        "select provides from packages where package = $1 and release = $2",
-        package, release)
+    async with await connect_udd_mirror() as conn:
+        provides = await conn.fetchval(
+            "select provides from packages where package = $1 and release = $2",
+            package, release)
     if provides is not None:
         return [r[1] for r in parse_relations(provides)]
     return None
@@ -124,19 +129,19 @@ async def _package_provides(package: str, release: str) -> Optional[Version]:
 async def _package_essential(package: str, release: str) -> bool:
     from .udd import connect_udd_mirror
 
-    conn = await connect_udd_mirror()
-    return await conn.fetchval(
-        "select (essential = 'yes') from packages where package = $1 and release = $2",
-        package, release)
+    async with await connect_udd_mirror() as conn:
+        return await conn.fetchval(
+            "select (essential = 'yes') from packages where package = $1 and release = $2",
+            package, release)
 
 
 async def _package_build_essential(package: str, release: str) -> bool:
     from .udd import connect_udd_mirror
 
-    conn = await connect_udd_mirror()
-    depends = await conn.fetchval(
-        "select depends from packages where package = $1 and release = $2",
-        'build-essential', release)
+    async with await connect_udd_mirror() as conn:
+        depends = await conn.fetchval(
+            "select depends from packages where package = $1 and release = $2",
+            'build-essential', release)
 
     build_essential = set()
     for ws1, rel, ws2 in parse_relations(depends):
@@ -171,7 +176,7 @@ def drop_obsolete_depends(entry: List[PkgRelation], checker: PackageChecker):
     dropped = []
     for pkgrel in entry:
         newrel = pkgrel
-        if pkgrel.version is not None:
+        if pkgrel.version is not None and pkgrel.name != 'debhelper':
             compat_version = checker.package_version(pkgrel.name)
             logging.debug(
                 "Relation: %s. Upgrade release %s has %r ",
@@ -320,7 +325,8 @@ def drop_old_relations(editor, compat_release: str, upgrade_release: str) -> Lis
 
 def update_maintscripts(
         wt: WorkingTree, subpath: str, checker: PackageChecker, package: str,
-        allow_reformatting: bool = False):
+        allow_reformatting: bool = False
+        ) -> List[Tuple[str, List[Tuple[int, str, Version]]]]:
     ret = []
     for entry in os.scandir(wt.abspath(os.path.join(subpath))):
         if not (entry.name == "maintscript" or entry.name.endswith(".maintscript")):
@@ -669,6 +675,9 @@ def main():  # noqa: C901
     except ChangeConflict as e:
         report_fatal('change-conflict', 'Generated file changes conflict: %s' % e)
         return 1
+    except UddTimeout:
+        report_fatal('udd-timeout', 'Timeout communicating with UDD')
+        return 1
 
     if not result:
         report_okay("nothing-to-do", "no obsolete constraints")
