@@ -15,20 +15,26 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Support for acessing UDD."""
+"""Support for accessing UDD."""
 
-_udd = None
+import asyncio
+
+
+_pool = None
 
 
 async def connect_udd_mirror():
     import asyncpg
-    global _udd
-    if _udd:
-        return _udd
-    _udd = await asyncpg.connect(
-        database="udd",
-        user="udd-mirror",
-        password="udd-mirror",
-        port=5432,
-        host="udd-mirror.debian.net")
-    return _udd
+
+    global _pool
+    if not _pool:
+        loop = asyncio.get_event_loop()
+        _pool = await asyncpg.create_pool(
+            database="udd",
+            user="udd-mirror",
+            password="udd-mirror",
+            port=5432,
+            host="udd-mirror.debian.net",
+            loop=loop,
+        )
+    return _pool.acquire()
